==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/en/xtcommonHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "select lines using reference file"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define TKYT "a list of attributes of an input file (mandatory)"
#define TKYC ""

/*-K*/
#define MKYT "a list of attributes of a reference file."
#define MKYC "a list of attributes of a reference file. It is used when the attribute names are different from those by -k."

/*-m*/
#define MSTT "reference file name"
#define MSTC "soecify the reference file name"

/*-r*/
#define REVT "reverse the selection condition"
#define REVC "select the lines which do not satisfy the selection condition."

/*-u*/
#define NOFT C_NOFT
#define NOFC C_NOFC

/*-H*/
#define HAST "hashing is used for selection"
#define HASC "This will improve the performance if the input file is large and the reference file is small."

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS " Comparing an input file and a reference file, this command selects the lines of an input file such that the  value of the attribute specified by -k matches  one of  those of values of the attribute specified by -K in the reference file."

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtcommon -k customerID -m ref.xt -i dat.xt -o rsl.xt\n\
xtcommon -k customerID -K customer -m ref.xt -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtselstr,xtsel,xtjoin,xtnjoin"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/* DocBookauthorǤηϤ                                        */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre3.tar.gz: musashi-core-1.0.4-pre3/help/en/xtcommonHelp.h <==
#include "commonHelp.h"
/*============================================================================*/
/* Management of messages common to command help, man, and musashi GUI                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "select lines using reference file"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define TKYT "a list of attributes of an input file (mandatory)"
#define TKYC ""

/*-K*/
#define MKYT "a list of attributes of a reference file."
#define MKYC "a list of attributes of a reference file. It is used when the attribute names are different from those by -k."

/*-m*/
#define MSTT "reference file name"
#define MSTC "soecify the reference file name"

/*-r*/
#define REVT "reverse the selection condition"
#define REVC "select the lines which do not satisfy the selection condition."

/*-u*/
#define NOFT C_NOFT
#define NOFC C_NOFC

/*-H*/
#define HAST "hashing is used for selection"
#define HASC "This will improve the performance if the input file is large and the reference file is small."

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS " Compare and select common key attributes specified by -k in the input file with records in the reference file that matches the key attributes specified by -k when the name of key attribute is different. When the option -r is used, attribute selection will be inverted, which in turn selects attributes which does not match the ones in the reference file. The option -u can be used to discharge records that are not selected. "

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtcommon -k customerID -m ref.xt -i dat.xt -o rsl.xt\n\
xtcommon -k customerID -K customer -m ref.xt -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtselstr,xtsel,xtjoin,xtnjoin"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/* DocBookauthorǤηϤ                                        */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
